import * as plugins from '../wcctools.plugins.js';
import { DeesElement, property, html, customElement, type TemplateResult } from '@design.estate/dees-element';
import { WccDashboard } from './wcc-dashboard.js';

export type TElementType = 'element' | 'page';

@customElement('wcc-sidebar')
export class WccSidebar extends DeesElement {
  @property({ attribute: false })
  public selectedItem: DeesElement | (() => TemplateResult);

  @property({ attribute: false })
  public selectedType: TElementType;

  @property()
  public dashboardRef: WccDashboard;

  public render(): TemplateResult {
    return html`
      <link href="https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined:opsz,wght,FILL,GRAD@20..48,100..700,0..1,-50..200" rel="stylesheet" />
      <style>
        :host {
          /* CSS Variables - Always dark theme to match wcc-properties */
          --background: #0a0a0a;
          --foreground: #e5e5e5;
          --card: #0f0f0f;
          --card-foreground: #f0f0f0;
          --muted: #1a1a1a;
          --muted-foreground: #666;
          --accent: #222;
          --accent-foreground: #fff;
          --border: rgba(255, 255, 255, 0.06);
          --input: #141414;
          --primary: #3b82f6;
          --primary-foreground: #fff;
          --ring: #3b82f6;
          --radius: 4px;

          display: block;
          border-right: 1px solid rgba(255, 255, 255, 0.08);
          font-family: 'Inter', -apple-system, BlinkMacSystemFont, 'Segoe UI', 'Roboto', sans-serif;
          font-size: 14px;
          box-sizing: border-box;
          position: absolute;
          left: 0px;
          width: 200px;
          top: 0px;
          bottom: 0px;
          overflow-y: auto;
          overflow-x: hidden;
          background: var(--background);
          color: var(--foreground);
        }

        .menu {
          padding: 0.5rem 0;
        }

        h3 {
          padding: 0.3rem 0.75rem;
          font-size: 0.65rem;
          font-weight: 500;
          text-transform: uppercase;
          letter-spacing: 0.08em;
          color: #888;
          margin: 0;
          margin-top: 0.5rem;
          background: rgba(59, 130, 246, 0.03);
          border-bottom: 1px solid var(--border);
          border-top: 1px solid var(--border);
        }

        h3:first-child {
          margin-top: 0;
        }

        .material-symbols-outlined {
          font-family: 'Material Symbols Outlined';
          font-weight: normal;
          font-style: normal;
          font-size: 16px;
          display: inline-block;
          line-height: 1;
          text-transform: none;
          letter-spacing: normal;
          word-wrap: normal;
          white-space: nowrap;
          direction: ltr;
          font-variation-settings: 'FILL' 0, 'wght' 300, 'GRAD' 0, 'opsz' 24;
          opacity: 0.5;
        }

        .selectOption {
          user-select: none;
          position: relative;
          margin: 0.125rem 0.5rem;
          padding: 0.5rem 0.75rem;
          transition: all 0.15s ease;
          display: grid;
          grid-template-columns: 20px 1fr;
          align-items: center;
          gap: 0.5rem;
          border-radius: var(--radius);
          cursor: pointer;
          font-size: 0.75rem;
          color: #999;
          background: transparent;
        }
        
        .selectOption:hover {
          background: rgba(59, 130, 246, 0.05);
          color: #bbb;
        }

        .selectOption:hover .material-symbols-outlined {
          opacity: 0.7;
        }

        .selectOption.selected {
          background: rgba(59, 130, 246, 0.15);
          color: var(--primary);
        }

        .selectOption.selected .material-symbols-outlined {
          opacity: 1;
          font-variation-settings: 'FILL' 1, 'wght' 400, 'GRAD' 0, 'opsz' 24;
        }

        .selectOption.selected:hover {
          background: rgba(59, 130, 246, 0.2);
          color: var(--primary);
        }

        .selectOption .text {
          display: block;
          overflow: hidden;
          text-overflow: ellipsis;
          white-space: nowrap;
          font-weight: 400;
        }

        ::-webkit-scrollbar {
          width: 8px;
        }

        ::-webkit-scrollbar-track {
          background: transparent;
        }

        ::-webkit-scrollbar-thumb {
          background: rgba(255, 255, 255, 0.1);
          border-radius: 4px;
        }

        ::-webkit-scrollbar-thumb:hover {
          background: rgba(255, 255, 255, 0.2);
        }
      </style>
      <div class="menu">
        <h3>Pages</h3>
        ${(() => {
          const pages = Object.keys(this.dashboardRef.pages);
          return pages.map(pageName => {
            const item = this.dashboardRef.pages[pageName];
            return html`
              <div
                class="selectOption ${this.selectedItem === item ? 'selected' : null}"
                @click=${async () => {
                  const domtools = await plugins.deesDomtools.DomTools.setupDomTools();
                  this.selectItem('page', pageName, item);
                }}
              >
                <i class="material-symbols-outlined">insert_drive_file</i>
                <div class="text">${pageName}</div>
              </div>
            `;
          });
        })()}
        <h3>Elements</h3>
        ${(() => {
          const elements = Object.keys(this.dashboardRef.elements);
          return elements.map(elementName => {
            const item = this.dashboardRef.elements[elementName];
            return html`
              <div
                class="selectOption ${this.selectedItem === item ? 'selected' : null}"
                @click=${async () => {
                  const domtools = await plugins.deesDomtools.DomTools.setupDomTools();
                  this.selectItem('element', elementName, item);
                }}
              >
                <i class="material-symbols-outlined">featured_video</i>
                <div class="text">${elementName}</div>
              </div>
            `;
          });
        })()}
      </div>
    `;
  }

  public selectItem(typeArg: TElementType, itemNameArg: string, itemArg: (() => TemplateResult) | DeesElement) {
    console.log('selected item');
    console.log(itemNameArg);
    console.log(itemArg);
    this.selectedItem = itemArg;
    this.selectedType = typeArg;
    this.dispatchEvent(
      new CustomEvent('selectedType', {
        detail: typeArg
      })
    );
    this.dispatchEvent(
      new CustomEvent('selectedItemName', {
        detail: itemNameArg
      })
    );
    this.dispatchEvent(
      new CustomEvent('selectedItem', {
        detail: itemArg
      })
    );
    
    this.dashboardRef.buildUrl();
  }
}
